%define		wx_ver 3.2
%define		realname SLADE

# comment out if not prerel
#define prel	b4

# rel for bumping
%define rel	1

Summary:	An editor for DOOM maps and WAD/PK3 archives
Name:		slade
Version:	3.2.6
Release:	%mkrel %{?prel:0.%prel.}%{rel}
License:	GPLv2+
Group:		Games/Arcade
Url:		https://github.com/sirjuddington/SLADE
Source0:	https://github.com/sirjuddington/%{realname}/archive/%{version}%{?prel:_%prel}/%{name}-%{version}%{?prel:_%prel}.tar.gz

Patch0:		basepk3.diff
Patch1:		slade-cmakelists.patch
# A simple patch to fix the build with luaopen_bit32
Patch3:		luaopen_utf8.patch

BuildRequires:	cmake
BuildRequires:	imagemagick
BuildRequires:	lua5.1-devel
BuildRequires:	lua5.1-bit32
BuildRequires:	p7zip
BuildRequires:	dumb-devel
BuildRequires:	freeimage-devel
BuildRequires:	wxgtk%{wx_ver}-devel
BuildRequires:	pkgconfig(fluidsynth)
BuildRequires:	pkgconfig(fmt)
BuildRequires:	pkgconfig(ftgl)
BuildRequires:	pkgconfig(gl)
BuildRequires:	pkgconfig(glew)
BuildRequires:	pkgconfig(libcurl)
BuildRequires:	pkgconfig(libmpg123)
BuildRequires:	pkgconfig(sfml-all)
BuildRequires:	pkgconfig(x11)
BuildRequires:	libstdc++-static-devel

# The name is SLADE, so provide it just in case
# 2019-12-02 - kekepower
Provides:	SLADE = %{version}-%{release}
Provides:	SLADE3 = %{version}-%{release}

ExclusiveArch:	%{ix86} x86_64

%description
SLADE3 is a modern editor for Doom-engine based games and source ports.
It has the ability to view, modify, and write many different game-specific
formats, and even convert between some of them, or from/to other generic
formats such as PNG.

%files
%doc README.md
%license LICENSE
%{_bindir}/slade
%{_datadir}/slade3/
%{_iconsdir}/hicolor/scalable/apps/net.mancubus.SLADE.svg
%{_datadir}/applications/net.mancubus.SLADE.desktop
%{_metainfodir}/net.mancubus.SLADE.metainfo.xml


#----------------------------------------------------------------------------

%prep
%autosetup -p1 -n %{realname}-%{version}%{?prel:_%prel}

sed -i '/#include <FreeImage.h>/a #undef _WINDOWS_ ' src/common.h

# std::filesystem components can be used without -lstdc++fs with gcc >= 9
sed -i -e '/lstdc++fs/d' src/CMakeLists.txt

%build
%cmake \
	-DUSE_WEBKIT_STARTPAGE:BOOL=ON \
	-DUSE_WX_EXCEPTION_HANDLER=0 \
	-DWX_GTK3=ON \
	-DNO_WEBVIEW=ON \
	-DwxWidgets_CONFIG_EXECUTABLE=%{_bindir}/wx-config-%{wx_ver} \
	-DUSE_SYSTEM_DUMB=ON \
	-DUSE_SYSTEM_FMT=ON \
	-DBUILD_PK3=ON
%cmake_build

%install
%cmake_install

pushd misc
for txtfile in detect_functions.txt old-simage-formats.txt stuff.txt udmf11.txt \
		udmf_zdoom.txt usdf.txt usdf_zdoom.txt
do
	install -Dm644 $txtfile %{buildroot}%{_datadir}/slade3/misc/${txtfile}
done
popd



%changelog
* Wed May 29 2024 kekepower <kekepower> 3.2.6-1.mga10
+ Revision: 2068617
- Update to version 3.2.6

* Thu Dec 21 2023 kekepower <kekepower> 3.2.5-1.mga10
+ Revision: 2020698
- Update to version 3.2.5

* Thu Jun 22 2023 kekepower <kekepower> 3.2.4-1.mga9
+ Revision: 1962792
- Update to version 3.2.4

* Sun Jun 04 2023 kekepower <kekepower> 3.2.3-1.mga9
+ Revision: 1960878
- Update to version 3.2.3

* Sat Apr 01 2023 kekepower <kekepower> 3.2.2-1.mga9
+ Revision: 1951159
- Update to version 3.2.2
- Remove upstreamed Patch10

* Wed Dec 28 2022 daviddavid <daviddavid> 3.2.1-6.mga9
+ Revision: 1927437
- use system fmt and dumb (from gentoo)

* Wed Dec 28 2022 daviddavid <daviddavid> 3.2.1-5.mga9
+ Revision: 1927290
- rebuild for new libfmt

* Thu Oct 13 2022 papoteur <papoteur> 3.2.1-4.mga9
+ Revision: 1896743
- Rebuild for libfmt 9.1.0

* Fri Jul 15 2022 wally <wally> 3.2.1-3.mga9
+ Revision: 1868971
- rebuild for wxgtk 3.2.0

* Sun Jun 12 2022 wally <wally> 3.2.1-2.mga9
+ Revision: 1864107
- rebuild for wxgtk 3.1.7

* Fri May 13 2022 kekepower <kekepower> 3.2.1-1.mga9
+ Revision: 1858021
- Update to version 3.2.1

* Mon May 09 2022 kekepower <kekepower> 3.2.0-1.mga9
+ Revision: 1857117
- Add upstream patch to build with wxgtk3.1.6
- Add upstream patch for wxgtk 3.1.6 compatability
- Add simple patch to fix build with lua5.1-bit32
- Update to version 3.2.0 final
+ wally <wally>
- rebuild for wxgtk 3.1.6

* Tue Apr 05 2022 kekepower <kekepower> 3.2.0-0.b4.1.mga9
+ Revision: 1844957
- Update to version 3.2.0b4

* Mon Apr 04 2022 umeabot <umeabot> 3.2.0-0.b3.7.mga9
+ Revision: 1844059
- Mageia 9 Mass Rebuild

* Sat Jan 15 2022 wally <wally> 3.2.0-0.b3.6.mga9
+ Revision: 1768477
- rebuild for wxgtk 3.1.5 with working wxSizer::SetSizeHints()

* Tue Jan 04 2022 wally <wally> 3.2.0-0.b3.5.mga9
+ Revision: 1766836
- rebuild again for wxgtk 3.1.5 without wxGLCanvas Wayland/EGL backend support

* Mon Jan 03 2022 wally <wally> 3.2.0-0.b3.4.mga9
+ Revision: 1766414
- rebuild for wxgtk 3.1.5 with wxGLCanvas Wayland/EGL backend enabled

* Sat Jan 01 2022 wally <wally> 3.2.0-0.b3.3.mga9
+ Revision: 1765709
- rebuild for wxgtk 3.1.5 to resolve 'Symbol X has different size in shared object, consider re-linking' error

* Thu Aug 05 2021 luigiwalser <luigiwalser> 3.2.0-0.b3.2.mga9
+ Revision: 1739428
- rebuild for fluidsynth

* Fri Jun 25 2021 wally <wally> 3.2.0-0.b3.1.mga9
+ Revision: 1732213
- new version 3.2.0 beta 3

* Fri Jun 25 2021 wally <wally> 3.2.0-0.b2.6.mga9
+ Revision: 1732212
- rebuild for fmt 8.0.0

* Thu Jun 24 2021 wally <wally> 3.2.0-0.b2.5.mga9
+ Revision: 1732147
- rebuild for fmt 8.0.0

* Sun Apr 11 2021 wally <wally> 3.2.0-0.b2.4.mga9
+ Revision: 1714687
- build with lua 5.1 as lua 5.4 isn't supported

* Fri Jan 01 2021 wally <wally> 3.2.0-0.b2.3.mga8
+ Revision: 1667727
- rebuild for wxgtk pre 3.1.5 snapshot

* Wed Dec 02 2020 luigiwalser <luigiwalser> 3.2.0-0.b2.2.mga8
+ Revision: 1651617
- rebuild for glew

* Mon Aug 17 2020 wally <wally> 3.2.0-0.b2.1.mga8
+ Revision: 1614591
- new version 3.2.0 beta2
- rebuild for new wxgtk 3.1.4

* Fri Mar 06 2020 kekepower <kekepower> 3.1.11-1.mga8
+ Revision: 1554502
- Update to version 3.1.11

* Wed Feb 19 2020 kekepower <kekepower> 3.1.9-1.mga8
+ Revision: 1543587
- Update to version 3.1.9

* Tue Feb 18 2020 umeabot <umeabot> 3.1.8-3.mga8
+ Revision: 1539215
- Mageia 8 Mass Rebuild
+ wally <wally>
- build with new cmake macros

* Mon Dec 02 2019 kekepower <kekepower> 3.1.8-2.mga8
+ Revision: 1464040
- Bump rel for build on i586 and x86_64
- Exclude ARM and aarch64 for now
- Update to version 3.1.8
- imported package slade

